=======
sttn
=======


Library for spatio-temporal transactional network analysis


Description
===========

Multiple real-world processes can be described by a list of transactions that include temporal and spatial dimensions, while transactions themself form a network between entities.
Examples include credit card transactions, phone calls, taxi trips, social network interactions and the list goes on and on.

STTN is an attempt to combine elements of network, time and network analysis within one framework.
